@@ -26,7 +26,7 @@ class Dialog(Component, Window):
         
        
         Component.__init__(self)
-        Window.__init__(self, Window.TYPE_DIALOG)
+        Window.__init__(self, Window.TYPE_TOPLEVEL)
         self.connect_closed(self.__on_close_window)
         
         
@@ -37,10 +37,6 @@ class Dialog(Component, Window):
 
     def set_visible(self, v):
     
-        if (v):
-            self.set_size(gtk.gdk.screen_width(),
-                          gtk.gdk.screen_height() - 120)
-
         Window.set_visible(self, v)
 
 
