@@ -2,6 +2,9 @@ def get_classes():
 
     from AudioPlayer import AudioPlayer
     from AudioThumbnailer import AudioThumbnailer
+    from AudioInspector import AudioInspector
+    
     return [AudioPlayer,
-            AudioThumbnailer]
+            AudioThumbnailer,
+            AudioInspector]
 
