@@ -7,11 +7,18 @@ import values
 import os
 
 
-#_BM_DIR = os.path.join(values.USER_DIR, "bookmarks")
 _BM_ZIP = os.path.join(values.USER_DIR, "media_bookmarks.zip")
 
 
+
 def set_bookmarks(f, bookmarks):
+    """
+    Sets bookmarks in the given file. Pass an empty list of bookmarks to
+    clear all bookmarks in that file.
+    
+    @param f: file object
+    @param bookmarks: list of bookmarks
+    """
 
     out = " ".join([ `b` for b in bookmarks ])
     try:
@@ -20,9 +27,15 @@ def set_bookmarks(f, bookmarks):
         bm_zip.close()
     except:
         pass
-    
+        
     
 def get_bookmarks(f):
+    """
+    Returns the bookmarks set in the given file.
+    
+    @param f: file object
+    @return: list of bookmarks
+    """
 
     try:
         bm_zip = ZipFile(_BM_ZIP, "r")
@@ -33,42 +46,11 @@ def get_bookmarks(f):
         return []
 
 
+def clear_all():
+    """
+    Clears all bookmarks.
+    @since: 0.96.5
+    """
 
-"""
-def _ensure_bm_dir():
-
-    if (not os.path.exists(_BM_DIR)):
-        try:
-            os.makedirs(_BM_DIR)
-        except:
-            pass
-
-
-def set_bookmarks(f, bookmarks):
-
-    _ensure_bm_dir()
-    bm_file = os.path.join(_BM_DIR, f.md5)
-    out = " ".join([ `b` for b in bookmarks ])
-    if (not bookmarks):
-        try:            
-            os.unlink(bm_file)
-        except:
-            pass
-    else:
-        try:
-            open(bm_file, "w").write(out)
-        except:
-            pass
-    
-    
-def get_bookmarks(f):
-
-    _ensure_bm_dir()
-    bm_file = os.path.join(_BM_DIR, f.md5)
-    try:
-        data = open(bm_file, "r").read()
-        return [ float(b) for b in data.split() ]
-    except:
-        return []
-"""
+    os.unlink(_BM_ZIP)
 
